# dora-pyaudio

## Getting started

- (MacOS) Install `portaudio`

```bash
brew install portaudio
```

- (Linux) Install `portaudio`

```bash
sudo apt-get install portaudio19-dev python-all-dev
```

- Install it with pip:

```bash
pip install -e .
```

## Contribution Guide

- Format with [ruff](https://docs.astral.sh/ruff/):

```bash
ruff check . --fix
```

- Lint with ruff:

```bash
ruff check .
```

- Test with [pytest](https://github.com/pytest-dev/pytest)

```bash
pytest . # Test
```

## YAML Specification

## Examples

## License

dora-pyaudio's code are released under the MIT License
